# Coscine.ApiClient.Core - the C# library for the Coscine Web API

Coscine (short for <b>CO</b>llaborative <b>SC</b>ientific <b>IN</b>tegration <b>E</b>nvironment) is the research data management platform for your research project.

This C# SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0
- SDK version: 1.0.0
- Generator version: 7.11.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.CSharpClientCodegen

<a id="frameworks-supported"></a>
## Frameworks supported

<a id="dependencies"></a>
## Dependencies

- [RestSharp](https://www.nuget.org/packages/RestSharp) - 112.0.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 13.0.2 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.8.0 or later
- [System.ComponentModel.Annotations](https://www.nuget.org/packages/System.ComponentModel.Annotations) - 5.0.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
Install-Package System.ComponentModel.Annotations
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742).
NOTE: RestSharp for .Net Core creates a new socket for each api call, which can lead to a socket exhaustion problem. See [RestSharp#1406](https://github.com/restsharp/RestSharp/issues/1406).

<a id="installation"></a>
## Installation
Run the following command to generate the DLL
- [Mac/Linux] `/bin/sh build.sh`
- [Windows] `build.bat`

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:
```csharp
using Coscine.ApiClient.Core.Api;
using Coscine.ApiClient.Core.Client;
using Coscine.ApiClient.Core.Model;
```
<a id="packaging"></a>
## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out Coscine.ApiClient.Core.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.

<a id="usage"></a>
## Usage

To use the API client with a HTTP proxy, setup a `System.Net.WebProxy`
```csharp
Configuration c = new Configuration();
System.Net.WebProxy webProxy = new System.Net.WebProxy("http://myProxyUrl:80/");
webProxy.Credentials = System.Net.CredentialCache.DefaultCredentials;
c.Proxy = webProxy;
```

<a id="getting-started"></a>
## Getting Started

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Coscine.ApiClient.Core.Api;
using Coscine.ApiClient.Core.Client;
using Coscine.ApiClient.Core.Model;

namespace Example
{
    public class Example
    {
        public static void Main()
        {

            Configuration config = new Configuration();
            config.BasePath = "https://coscine-api-hristov.web.vulcanus.otc.coscine.dev/coscine";
            // Configure API key authorization: Bearer
            config.ApiKey.Add("Authorization", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // config.ApiKeyPrefix.Add("Authorization", "Bearer");

            var apiInstance = new AdminApi(config);

            try
            {
                // Responds with the HTTP methods allowed for the endpoint.
                apiInstance.ApiV2AdminOptions();
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling AdminApi.ApiV2AdminOptions: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }

        }
    }
}
```

<a id="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://coscine-api-hristov.web.vulcanus.otc.coscine.dev/coscine*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminApi* | [**ApiV2AdminOptions**](docs/AdminApi.md#apiv2adminoptions) | **OPTIONS** /api/v2/admin | Responds with the HTTP methods allowed for the endpoint.
*AdminApi* | [**GetAllActivityLogs**](docs/AdminApi.md#getallactivitylogs) | **GET** /api/v2/admin/activity-logs | Retrieves all activity logs.
*AdminApi* | [**GetAllProjects**](docs/AdminApi.md#getallprojects) | **GET** /api/v2/admin/projects | Retrieves all projects.
*AdminApi* | [**GetAllResources**](docs/AdminApi.md#getallresources) | **GET** /api/v2/admin/resources | Retrieves all resources.
*AdminApi* | [**GetAllUsers**](docs/AdminApi.md#getallusers) | **GET** /api/v2/admin/users | Retrieves all users.
*AdminApi* | [**GetDeployedGraphs**](docs/AdminApi.md#getdeployedgraphs) | **GET** /api/v2/admin/graphs | Gets all deployed graphs.
*AdminApi* | [**GetMetadataGraph**](docs/AdminApi.md#getmetadatagraph) | **GET** /api/v2/admin/metadata/{graph} | Gets a metadata graph.
*AdminApi* | [**PatchMetadata**](docs/AdminApi.md#patchmetadata) | **PATCH** /api/v2/admin/metadata/{graph} | Patches a metadata graph.
*AdminApi* | [**UpdateMetadataGraph**](docs/AdminApi.md#updatemetadatagraph) | **PUT** /api/v2/admin/metadata/{graph} | Updates a metadata graph.
*ApplicationProfileApi* | [**ApiV2ApplicationProfilesOptions**](docs/ApplicationProfileApi.md#apiv2applicationprofilesoptions) | **OPTIONS** /api/v2/application-profiles | Responds with the HTTP methods allowed for the endpoint.
*ApplicationProfileApi* | [**CreateApplicationProfileRequest**](docs/ApplicationProfileApi.md#createapplicationprofilerequest) | **POST** /api/v2/application-profiles/requests | Submits a request to create a new application profile.
*ApplicationProfileApi* | [**GetApplicationProfile**](docs/ApplicationProfileApi.md#getapplicationprofile) | **GET** /api/v2/application-profiles/profiles/{profile} | Retrieves an application profile by its URI.
*ApplicationProfileApi* | [**GetApplicationProfiles**](docs/ApplicationProfileApi.md#getapplicationprofiles) | **GET** /api/v2/application-profiles/profiles | Retrieves all application profiles.
*ApplicationProfileApi* | [**GetRawApplicationProfile**](docs/ApplicationProfileApi.md#getrawapplicationprofile) | **GET** /api/v2/application-profiles/profiles/{profile}/raw | Retrieves the `raw` application profile definition by its URI.
*BlobApi* | [**ApiV2ProjectsProjectIdResourcesResourceIdBlobsOptions**](docs/BlobApi.md#apiv2projectsprojectidresourcesresourceidblobsoptions) | **OPTIONS** /api/v2/projects/{projectId}/resources/{resourceId}/blobs | Responds with the HTTP methods allowed for the endpoint.
*BlobApi* | [**CreateBlob**](docs/BlobApi.md#createblob) | **POST** /api/v2/projects/{projectId}/resources/{resourceId}/blobs/{key} | Creates a new blob for a resource.
*BlobApi* | [**DeleteBlob**](docs/BlobApi.md#deleteblob) | **DELETE** /api/v2/projects/{projectId}/resources/{resourceId}/blobs/{key} | Deletes a blob from a resource.
*BlobApi* | [**GetBlob**](docs/BlobApi.md#getblob) | **GET** /api/v2/projects/{projectId}/resources/{resourceId}/blobs/{key} | Download a blob from a resource.
*BlobApi* | [**UpdateBlob**](docs/BlobApi.md#updateblob) | **PUT** /api/v2/projects/{projectId}/resources/{resourceId}/blobs/{key} | Updates an existing blob of a resource.
*DisciplineApi* | [**ApiV2DisciplinesOptions**](docs/DisciplineApi.md#apiv2disciplinesoptions) | **OPTIONS** /api/v2/disciplines | Responds with the HTTP methods allowed for the endpoint.
*DisciplineApi* | [**GetDiscipline**](docs/DisciplineApi.md#getdiscipline) | **GET** /api/v2/disciplines/{disciplineId} | Retrieves a discipline with the specified ID.
*DisciplineApi* | [**GetDisciplines**](docs/DisciplineApi.md#getdisciplines) | **GET** /api/v2/disciplines | Retrieves all disciplines.
*HandleApi* | [**ApiV2HandlesOptions**](docs/HandleApi.md#apiv2handlesoptions) | **OPTIONS** /api/v2/handles | Responds with the HTTP methods allowed for the endpoint.
*HandleApi* | [**GetHandle**](docs/HandleApi.md#gethandle) | **GET** /api/v2/handles/{prefix}/{suffix} | Retrieves all values of a handle by its PID.
*HandleApi* | [**UpdateHandle**](docs/HandleApi.md#updatehandle) | **PUT** /api/v2/handles/{prefix}/{suffix} | Updates a handle.
*LanguageApi* | [**ApiV2LanguagesOptions**](docs/LanguageApi.md#apiv2languagesoptions) | **OPTIONS** /api/v2/languages | Responds with the HTTP methods allowed for the endpoint.
*LanguageApi* | [**GetLanguage**](docs/LanguageApi.md#getlanguage) | **GET** /api/v2/languages/{languageId} | Retrieves a language by ID.
*LanguageApi* | [**GetLanguages**](docs/LanguageApi.md#getlanguages) | **GET** /api/v2/languages | Retrieves all languages.
*LicenseApi* | [**ApiV2LicensesOptions**](docs/LicenseApi.md#apiv2licensesoptions) | **OPTIONS** /api/v2/licenses | Responds with the HTTP methods allowed for the endpoint.
*LicenseApi* | [**GetLicense**](docs/LicenseApi.md#getlicense) | **GET** /api/v2/licenses/{licenseId} | Retrieves a license with the specified ID.
*LicenseApi* | [**GetLicenses**](docs/LicenseApi.md#getlicenses) | **GET** /api/v2/licenses | Retrieves all licenses.
*MaintenanceApi* | [**ApiV2MaintenancesOptions**](docs/MaintenanceApi.md#apiv2maintenancesoptions) | **OPTIONS** /api/v2/maintenances | Responds with the HTTP methods allowed for the endpoint.
*MaintenanceApi* | [**GetCurrentMaintenances**](docs/MaintenanceApi.md#getcurrentmaintenances) | **GET** /api/v2/maintenances | Retrieves the current maintenance messages.
*OrganizationApi* | [**ApiV2OrganizationsOptions**](docs/OrganizationApi.md#apiv2organizationsoptions) | **OPTIONS** /api/v2/organizations | Responds with the HTTP methods allowed for the endpoint.
*OrganizationApi* | [**GetOrganization**](docs/OrganizationApi.md#getorganization) | **GET** /api/v2/organizations/{organizationRorUri} | Retrieves an organization.
*OrganizationApi* | [**GetOrganizations**](docs/OrganizationApi.md#getorganizations) | **GET** /api/v2/organizations | Retrieves all organizations.
*PidApi* | [**ApiV2PidsOptions**](docs/PidApi.md#apiv2pidsoptions) | **OPTIONS** /api/v2/pids | Responds with the HTTP methods allowed for the endpoint.
*PidApi* | [**GetPid**](docs/PidApi.md#getpid) | **GET** /api/v2/pids/{prefix}/{suffix} | Retrieves the Persistent Identifier (PID) for a given prefix and suffix.
*PidApi* | [**GetPids**](docs/PidApi.md#getpids) | **GET** /api/v2/pids | Retrieves all PIDs.
*PidApi* | [**SendRequestToOwner**](docs/PidApi.md#sendrequesttoowner) | **POST** /api/v2/pids/{prefix}/{suffix}/requests | Sends an inquiry to the owner of the given PID.
*ProjectApi* | [**ApiV2ProjectsOptions**](docs/ProjectApi.md#apiv2projectsoptions) | **OPTIONS** /api/v2/projects | Responds with the HTTP methods allowed for the endpoint.
*ProjectApi* | [**CreateProject**](docs/ProjectApi.md#createproject) | **POST** /api/v2/projects | Creates a new project.
*ProjectApi* | [**DeleteProject**](docs/ProjectApi.md#deleteproject) | **DELETE** /api/v2/projects/{projectId} | Deletes a project.
*ProjectApi* | [**GetProject**](docs/ProjectApi.md#getproject) | **GET** /api/v2/projects/{projectId} | Retrieves a project.
*ProjectApi* | [**GetProjects**](docs/ProjectApi.md#getprojects) | **GET** /api/v2/projects | Retrieves all projects.
*ProjectApi* | [**UpdateProject**](docs/ProjectApi.md#updateproject) | **PUT** /api/v2/projects/{projectId} | Updates a project.
*ProjectInvitationApi* | [**ApiV2ProjectsProjectIdInvitationsOptions**](docs/ProjectInvitationApi.md#apiv2projectsprojectidinvitationsoptions) | **OPTIONS** /api/v2/projects/{projectId}/invitations | Responds with the HTTP methods allowed for the endpoint.
*ProjectInvitationApi* | [**CreateProjectInvitation**](docs/ProjectInvitationApi.md#createprojectinvitation) | **POST** /api/v2/projects/{projectId}/invitations | Creates a project invitation for a specified project.
*ProjectInvitationApi* | [**DeleteProjectInvitation**](docs/ProjectInvitationApi.md#deleteprojectinvitation) | **DELETE** /api/v2/projects/{projectId}/invitations/{projectInvitationId} | Deletes a project invitation for a specified project.
*ProjectInvitationApi* | [**GetProjectInvitation**](docs/ProjectInvitationApi.md#getprojectinvitation) | **GET** /api/v2/projects/{projectId}/invitations/{projectInvitationId} | Retrieves a project invitation for a specified project.
*ProjectInvitationApi* | [**GetProjectInvitations**](docs/ProjectInvitationApi.md#getprojectinvitations) | **GET** /api/v2/projects/{projectId}/invitations | Retrieves all project invitations for a specified project.
*ProjectMemberApi* | [**AddMembership**](docs/ProjectMemberApi.md#addmembership) | **POST** /api/v2/projects/{projectId}/members | Creates a project membership for a specified project.
*ProjectMemberApi* | [**ApiV2ProjectsProjectIdMembersOptions**](docs/ProjectMemberApi.md#apiv2projectsprojectidmembersoptions) | **OPTIONS** /api/v2/projects/{projectId}/members | Responds with the HTTP methods allowed for the endpoint.
*ProjectMemberApi* | [**DeleteMembership**](docs/ProjectMemberApi.md#deletemembership) | **DELETE** /api/v2/projects/{projectId}/members/{membershipId} | Deletes a project membership for a specified project.
*ProjectMemberApi* | [**GetMembership**](docs/ProjectMemberApi.md#getmembership) | **GET** /api/v2/projects/{projectId}/members/{membershipId} | Retrieves a project membership for a specified project.
*ProjectMemberApi* | [**GetMemberships**](docs/ProjectMemberApi.md#getmemberships) | **GET** /api/v2/projects/{projectId}/members | Retrieves all project memberships for a specified project.
*ProjectMemberApi* | [**UpdateMembership**](docs/ProjectMemberApi.md#updatemembership) | **PUT** /api/v2/projects/{projectId}/members/{membershipId} | Updates a project membership for a specified project.
*ProjectPublicationRequestApi* | [**ApiV2ProjectsProjectIdPublicationsRequestsOptions**](docs/ProjectPublicationRequestApi.md#apiv2projectsprojectidpublicationsrequestsoptions) | **OPTIONS** /api/v2/projects/{projectId}/publications/requests | Responds with the HTTP methods allowed for the endpoint.
*ProjectPublicationRequestApi* | [**CreatePublicationRequest**](docs/ProjectPublicationRequestApi.md#createpublicationrequest) | **POST** /api/v2/projects/{projectId}/publications/requests | Creates a new publication request.
*ProjectPublicationRequestApi* | [**GetPublicationRequest**](docs/ProjectPublicationRequestApi.md#getpublicationrequest) | **GET** /api/v2/projects/{projectId}/publications/requests/{publicationRequestId} | Retrieves a publication request.
*ProjectQuotaApi* | [**ApiV2ProjectsProjectIdQuotasOptions**](docs/ProjectQuotaApi.md#apiv2projectsprojectidquotasoptions) | **OPTIONS** /api/v2/projects/{projectId}/quotas | Responds with the HTTP methods allowed for the endpoint.
*ProjectQuotaApi* | [**GetProjectQuota**](docs/ProjectQuotaApi.md#getprojectquota) | **GET** /api/v2/projects/{projectId}/quotas/{resourceTypeId} | Retrieves a project quota for a specified project and resource type.
*ProjectQuotaApi* | [**GetProjectQuotas**](docs/ProjectQuotaApi.md#getprojectquotas) | **GET** /api/v2/projects/{projectId}/quotas | Retrieves all project quotas for a specified project.
*ProjectQuotaApi* | [**UpdateProjectQuota**](docs/ProjectQuotaApi.md#updateprojectquota) | **PUT** /api/v2/projects/{projectId}/quotas/{resourceTypeId} | Updates a project quota for a specified project and resource type.
*ProjectResourceApi* | [**ApiV2ProjectsProjectIdResourcesOptions**](docs/ProjectResourceApi.md#apiv2projectsprojectidresourcesoptions) | **OPTIONS** /api/v2/projects/{projectId}/resources | Responds with the HTTP methods allowed for the endpoint.
*ProjectResourceApi* | [**CreateResourceForProject**](docs/ProjectResourceApi.md#createresourceforproject) | **POST** /api/v2/projects/{projectId}/resources | Creates a new resource for a specified project.
*ProjectResourceApi* | [**DeleteResourceForProject**](docs/ProjectResourceApi.md#deleteresourceforproject) | **DELETE** /api/v2/projects/{projectId}/resources/{resourceId} | Deletes a resource for a specified project.
*ProjectResourceApi* | [**GetResourceForProject**](docs/ProjectResourceApi.md#getresourceforproject) | **GET** /api/v2/projects/{projectId}/resources/{resourceId} | Retrieves a resource for a specified project.
*ProjectResourceApi* | [**GetResourcesForProject**](docs/ProjectResourceApi.md#getresourcesforproject) | **GET** /api/v2/projects/{projectId}/resources | Retrieves all resources for a specified project.
*ProjectResourceApi* | [**UpdateResourceForProject**](docs/ProjectResourceApi.md#updateresourceforproject) | **PUT** /api/v2/projects/{projectId}/resources/{resourceId} | Updates a resource for a specified project.
*ProjectResourceQuotaApi* | [**ApiV2ProjectsProjectIdResourcesResourceIdQuotaOptions**](docs/ProjectResourceQuotaApi.md#apiv2projectsprojectidresourcesresourceidquotaoptions) | **OPTIONS** /api/v2/projects/{projectId}/resources/{resourceId}/quota | Responds with the HTTP methods allowed for the endpoint.
*ProjectResourceQuotaApi* | [**GetQuotaForResourceForProject**](docs/ProjectResourceQuotaApi.md#getquotaforresourceforproject) | **GET** /api/v2/projects/{projectId}/resources/{resourceId}/quota | Retrieves the resource quota for a specific resource in a project.
*ProjectResourceTypeApi* | [**ApiV2ProjectsProjectIdResourceTypesOptions**](docs/ProjectResourceTypeApi.md#apiv2projectsprojectidresourcetypesoptions) | **OPTIONS** /api/v2/projects/{projectId}/resource-types | Responds with the HTTP methods allowed for the endpoint.
*ProjectResourceTypeApi* | [**GetAvailableResourceTypesInformationForProject**](docs/ProjectResourceTypeApi.md#getavailableresourcetypesinformationforproject) | **GET** /api/v2/projects/{projectId}/resource-types | Retrieves the available resource types information for a specific project.
*ProvenanceApi* | [**ApiV2ProjectsProjectIdResourcesResourceIdProvenanceOptions**](docs/ProvenanceApi.md#apiv2projectsprojectidresourcesresourceidprovenanceoptions) | **OPTIONS** /api/v2/projects/{projectId}/resources/{resourceId}/provenance | Responds with the HTTP methods allowed for the endpoint.
*ProvenanceApi* | [**GetSpecificProvenance**](docs/ProvenanceApi.md#getspecificprovenance) | **GET** /api/v2/projects/{projectId}/resources/{resourceId}/provenance/specific | Retrieves the specific provenance information associated with a resource.
*ProvenanceApi* | [**UpdateSpecificProvenance**](docs/ProvenanceApi.md#updatespecificprovenance) | **PUT** /api/v2/projects/{projectId}/resources/{resourceId}/provenance/specific | Updates existing specific provenance information of a resource.
*ResourceApi* | [**ApiV2ResourcesOptions**](docs/ResourceApi.md#apiv2resourcesoptions) | **OPTIONS** /api/v2/resources | Responds with the HTTP methods allowed for the endpoint.
*ResourceApi* | [**GetResource**](docs/ResourceApi.md#getresource) | **GET** /api/v2/resources/{resourceId} | Retrieves a resource by its ID.
*ResourceTypeApi* | [**ApiV2ResourceTypesOptions**](docs/ResourceTypeApi.md#apiv2resourcetypesoptions) | **OPTIONS** /api/v2/resource-types | Responds with the HTTP methods allowed for the endpoint.
*ResourceTypeApi* | [**GetAllResourceTypesInformation**](docs/ResourceTypeApi.md#getallresourcetypesinformation) | **GET** /api/v2/resource-types/types | Retrieves the entire global resource types information.
*ResourceTypeApi* | [**GetResourceTypeInformation**](docs/ResourceTypeApi.md#getresourcetypeinformation) | **GET** /api/v2/resource-types/types/{resourceTypeId} | Retrieves the resource type information for a specific resource type.
*ResourceTypeGitLabApi* | [**ApiV2ResourceTypesGitlabOptions**](docs/ResourceTypeGitLabApi.md#apiv2resourcetypesgitlaboptions) | **OPTIONS** /api/v2/resource-types/gitlab | Responds with the HTTP methods allowed for the endpoint.
*ResourceTypeGitLabApi* | [**GetAllGitlabBranchesForProject**](docs/ResourceTypeGitLabApi.md#getallgitlabbranchesforproject) | **GET** /api/v2/resource-types/gitlab/projects/{gitlabProjectId}/branches | Retrieves all branches of a GitLab project, that the user is a member of, based on the provided credentials.
*ResourceTypeGitLabApi* | [**GetAllGitlabProjects**](docs/ResourceTypeGitLabApi.md#getallgitlabprojects) | **GET** /api/v2/resource-types/gitlab/projects | Retrieves all GitLab projects, that the user is a member of, based on the provided credentials.
*ResourceTypeGitLabApi* | [**GetGitlabProject**](docs/ResourceTypeGitLabApi.md#getgitlabproject) | **GET** /api/v2/resource-types/gitlab/projects/{gitlabProjectId} | Retrieves a single GitLab project, that the user is a member of, based on the provided credentials.
*RoleApi* | [**ApiV2RolesOptions**](docs/RoleApi.md#apiv2rolesoptions) | **OPTIONS** /api/v2/roles | Responds with the HTTP methods allowed for the endpoint.
*RoleApi* | [**GetRole**](docs/RoleApi.md#getrole) | **GET** /api/v2/roles/{roleId} | Retrieves a role by ID.
*RoleApi* | [**GetRoles**](docs/RoleApi.md#getroles) | **GET** /api/v2/roles | Retrieves all roles.
*SearchApi* | [**ApiV2SearchOptions**](docs/SearchApi.md#apiv2searchoptions) | **OPTIONS** /api/v2/search | Responds with the HTTP methods allowed for the endpoint.
*SearchApi* | [**GetSearchResults**](docs/SearchApi.md#getsearchresults) | **GET** /api/v2/search | Retrieves a search result by given search parameters.
*SelfApi* | [**AcceptCurrentTos**](docs/SelfApi.md#acceptcurrenttos) | **POST** /api/v2/self/tos | Accepts the current Terms Of Service for the current authenticated user.
*SelfApi* | [**ApiV2SelfOptions**](docs/SelfApi.md#apiv2selfoptions) | **OPTIONS** /api/v2/self | Responds with the HTTP methods allowed for the endpoint.
*SelfApi* | [**ConfirmUserEmail**](docs/SelfApi.md#confirmuseremail) | **POST** /api/v2/self/emails | Confirms the email of a user.
*SelfApi* | [**GetCurrentUser**](docs/SelfApi.md#getcurrentuser) | **GET** /api/v2/self | Retrieves the current authenticated user.
*SelfApi* | [**InitiateUserMerge**](docs/SelfApi.md#initiateusermerge) | **POST** /api/v2/self/identities | Initiates user merging for the current user.
*SelfApi* | [**ResolveProjectInvitation**](docs/SelfApi.md#resolveprojectinvitation) | **POST** /api/v2/self/project-invitations | Resolves a project invitation for the authenticated user.
*SelfApi* | [**UpdateCurrentUser**](docs/SelfApi.md#updatecurrentuser) | **PUT** /api/v2/self | Updates the current authenticated user.
*SelfApiTokenApi* | [**ApiV2SelfApiTokensOptions**](docs/SelfApiTokenApi.md#apiv2selfapitokensoptions) | **OPTIONS** /api/v2/self/api-tokens | Responds with the HTTP methods allowed for the endpoint.
*SelfApiTokenApi* | [**CreateApiToken**](docs/SelfApiTokenApi.md#createapitoken) | **POST** /api/v2/self/api-tokens | Creates an API token for the current authenticated user.
*SelfApiTokenApi* | [**GetAllApiTokens**](docs/SelfApiTokenApi.md#getallapitokens) | **GET** /api/v2/self/api-tokens | Retrieves all API tokens for the current authenticated user.
*SelfApiTokenApi* | [**GetApiToken**](docs/SelfApiTokenApi.md#getapitoken) | **GET** /api/v2/self/api-tokens/{apiTokenId} | Retrieves an API token for the current authenticated user.
*SelfApiTokenApi* | [**RevokeToken**](docs/SelfApiTokenApi.md#revoketoken) | **DELETE** /api/v2/self/api-tokens/{apiTokenId} | Revokes an API token for the current authenticated user.
*SelfSessionApi* | [**ApiV2SelfSessionLogoutPost**](docs/SelfSessionApi.md#apiv2selfsessionlogoutpost) | **POST** /api/v2/self/session/logout | Initiate the Log out workflow.
*SelfSessionApi* | [**ApiV2SelfSessionOptions**](docs/SelfSessionApi.md#apiv2selfsessionoptions) | **OPTIONS** /api/v2/self/session | Responds with the HTTP methods allowed for the endpoint.
*SelfSessionApi* | [**Login**](docs/SelfSessionApi.md#login) | **GET** /api/v2/self/session | Initiate the login workflow with the default (NFDI4Ing AAI) provider.
*SelfSessionApi* | [**LoginWithProvider**](docs/SelfSessionApi.md#loginwithprovider) | **GET** /api/v2/self/session/{externalAuthenticatorId} | Initiate the login workflow with specific provider.
*SelfSessionApi* | [**Merge**](docs/SelfSessionApi.md#merge) | **GET** /api/v2/self/session/merge/{externalAuthenticatorId} | Initiate the merge workflow with specific provider.
*SystemStatusApi* | [**ApiV2SystemStatusOptions**](docs/SystemStatusApi.md#apiv2systemstatusoptions) | **OPTIONS** /api/v2/system/status | Responds with the HTTP methods allowed for the endpoint.
*SystemStatusApi* | [**GetInternalMessages**](docs/SystemStatusApi.md#getinternalmessages) | **GET** /api/v2/system/status/internal | Retrieves the internal messages.
*SystemStatusApi* | [**GetNocMessages**](docs/SystemStatusApi.md#getnocmessages) | **GET** /api/v2/system/status/noc | Retrieves the NOC messages.
*TitleApi* | [**ApiV2TitlesOptions**](docs/TitleApi.md#apiv2titlesoptions) | **OPTIONS** /api/v2/titles | Responds with the HTTP methods allowed for the endpoint.
*TitleApi* | [**GetTitle**](docs/TitleApi.md#gettitle) | **GET** /api/v2/titles/{titleId} | Retrieves a title by ID.
*TitleApi* | [**GetTitles**](docs/TitleApi.md#gettitles) | **GET** /api/v2/titles | Retrieves all titles.
*TosApi* | [**ApiV2TosOptions**](docs/TosApi.md#apiv2tosoptions) | **OPTIONS** /api/v2/tos | Responds with the HTTP methods allowed for the endpoint.
*TosApi* | [**GetTos**](docs/TosApi.md#gettos) | **GET** /api/v2/tos | Retrieves the current Terms of Service version.
*TreeApi* | [**ApiV2ProjectsProjectIdResourcesResourceIdTreesOptions**](docs/TreeApi.md#apiv2projectsprojectidresourcesresourceidtreesoptions) | **OPTIONS** /api/v2/projects/{projectId}/resources/{resourceId}/trees | Responds with the HTTP methods allowed for the endpoint.
*TreeApi* | [**CreateExtractedMetadataTree**](docs/TreeApi.md#createextractedmetadatatree) | **POST** /api/v2/projects/{projectId}/resources/{resourceId}/trees/metadata/extracted | Creates a new extracted metadata tree for a resource.
*TreeApi* | [**CreateMetadataTree**](docs/TreeApi.md#createmetadatatree) | **POST** /api/v2/projects/{projectId}/resources/{resourceId}/trees/metadata | Creates a new metadata tree for a resource.
*TreeApi* | [**DeleteMetadataTree**](docs/TreeApi.md#deletemetadatatree) | **DELETE** /api/v2/projects/{projectId}/resources/{resourceId}/trees/metadata | Deletes (invalidates) a metadata tree associated with a resource.
*TreeApi* | [**GetFileTree**](docs/TreeApi.md#getfiletree) | **GET** /api/v2/projects/{projectId}/resources/{resourceId}/trees/files | Retrieves the file tree associated with a resource.
*TreeApi* | [**GetMetadataTree**](docs/TreeApi.md#getmetadatatree) | **GET** /api/v2/projects/{projectId}/resources/{resourceId}/trees/metadata | Retrieves the metadata tree associated with a resource.
*TreeApi* | [**GetSpecificMetadataTree**](docs/TreeApi.md#getspecificmetadatatree) | **GET** /api/v2/projects/{projectId}/resources/{resourceId}/trees/metadata/specific | Retrieves the specific metadata tree associated with a resource.
*TreeApi* | [**UpdateExtractedMetadataTree**](docs/TreeApi.md#updateextractedmetadatatree) | **PUT** /api/v2/projects/{projectId}/resources/{resourceId}/trees/metadata/extracted | Updates an existing metadata tree of a resource.
*TreeApi* | [**UpdateMetadataTree**](docs/TreeApi.md#updatemetadatatree) | **PUT** /api/v2/projects/{projectId}/resources/{resourceId}/trees/metadata | Updates an existing metadata tree of a resource.
*UserApi* | [**ApiV2UsersOptions**](docs/UserApi.md#apiv2usersoptions) | **OPTIONS** /api/v2/users | Responds with the HTTP methods allowed for the endpoint.
*UserApi* | [**GetUsers**](docs/UserApi.md#getusers) | **GET** /api/v2/users | Retrieves all users.
*VisibilityApi* | [**ApiV2VisibilitiesOptions**](docs/VisibilityApi.md#apiv2visibilitiesoptions) | **OPTIONS** /api/v2/visibilities | Responds with the HTTP methods allowed for the endpoint.
*VisibilityApi* | [**GetVisibilities**](docs/VisibilityApi.md#getvisibilities) | **GET** /api/v2/visibilities | Retrieves all visibilities.
*VisibilityApi* | [**GetVisibility**](docs/VisibilityApi.md#getvisibility) | **GET** /api/v2/visibilities/{visibilityId} | Retrieves a visibility by ID.
*VocabularyApi* | [**ApiV2VocabulariesOptions**](docs/VocabularyApi.md#apiv2vocabulariesoptions) | **OPTIONS** /api/v2/vocabularies | Responds with the HTTP methods allowed for the endpoint.
*VocabularyApi* | [**GetVocabularies**](docs/VocabularyApi.md#getvocabularies) | **GET** /api/v2/vocabularies | Retrieves top-level instances from vocabularies.
*VocabularyApi* | [**GetVocabularyInstance**](docs/VocabularyApi.md#getvocabularyinstance) | **GET** /api/v2/vocabularies/instances/{instance} | Retrieves a single instance from a vocabulary.
*VocabularyApi* | [**GetVocabularyInstances**](docs/VocabularyApi.md#getvocabularyinstances) | **GET** /api/v2/vocabularies/instances | Retrieves vocabulary instances.


<a id="documentation-for-models"></a>
## Documentation for Models

 - [Model.AcceptedLanguage](docs/AcceptedLanguage.md)
 - [Model.ActivityLogDto](docs/ActivityLogDto.md)
 - [Model.ActivityLogDtoPagedResponse](docs/ActivityLogDtoPagedResponse.md)
 - [Model.ApiTokenDto](docs/ApiTokenDto.md)
 - [Model.ApiTokenDtoPagedResponse](docs/ApiTokenDtoPagedResponse.md)
 - [Model.ApiTokenDtoResponse](docs/ApiTokenDtoResponse.md)
 - [Model.ApiTokenForCreationDto](docs/ApiTokenForCreationDto.md)
 - [Model.ApplicationProfileDto](docs/ApplicationProfileDto.md)
 - [Model.ApplicationProfileDtoPagedResponse](docs/ApplicationProfileDtoPagedResponse.md)
 - [Model.ApplicationProfileDtoResponse](docs/ApplicationProfileDtoResponse.md)
 - [Model.ApplicationProfileForCreationDto](docs/ApplicationProfileForCreationDto.md)
 - [Model.ApplicationProfileForCreationDtoResponse](docs/ApplicationProfileForCreationDtoResponse.md)
 - [Model.ApplicationProfileForResourceCreationDto](docs/ApplicationProfileForResourceCreationDto.md)
 - [Model.ApplicationProfileMinimalDto](docs/ApplicationProfileMinimalDto.md)
 - [Model.CoscineHttpMethod](docs/CoscineHttpMethod.md)
 - [Model.DeployedGraphDto](docs/DeployedGraphDto.md)
 - [Model.DeployedGraphDtoPagedResponse](docs/DeployedGraphDtoPagedResponse.md)
 - [Model.DisciplineDto](docs/DisciplineDto.md)
 - [Model.DisciplineDtoPagedResponse](docs/DisciplineDtoPagedResponse.md)
 - [Model.DisciplineDtoResponse](docs/DisciplineDtoResponse.md)
 - [Model.DisciplineForProjectManipulationDto](docs/DisciplineForProjectManipulationDto.md)
 - [Model.DisciplineForResourceManipulationDto](docs/DisciplineForResourceManipulationDto.md)
 - [Model.DisciplineForUserManipulationDto](docs/DisciplineForUserManipulationDto.md)
 - [Model.ExtractedMetadataTreeForCreationDto](docs/ExtractedMetadataTreeForCreationDto.md)
 - [Model.ExtractedMetadataTreeForUpdateDto](docs/ExtractedMetadataTreeForUpdateDto.md)
 - [Model.FileActionDto](docs/FileActionDto.md)
 - [Model.FileActionHttpMethod](docs/FileActionHttpMethod.md)
 - [Model.FileActionsDto](docs/FileActionsDto.md)
 - [Model.FileSystemStorageOptionsDto](docs/FileSystemStorageOptionsDto.md)
 - [Model.FileTreeDto](docs/FileTreeDto.md)
 - [Model.FileTreeDtoPagedResponse](docs/FileTreeDtoPagedResponse.md)
 - [Model.FixedValueForResourceManipulationDto](docs/FixedValueForResourceManipulationDto.md)
 - [Model.GitLabOptionsDto](docs/GitLabOptionsDto.md)
 - [Model.GitlabBranchDto](docs/GitlabBranchDto.md)
 - [Model.GitlabBranchDtoIEnumerableResponse](docs/GitlabBranchDtoIEnumerableResponse.md)
 - [Model.GitlabProjectDto](docs/GitlabProjectDto.md)
 - [Model.GitlabProjectDtoIEnumerableResponse](docs/GitlabProjectDtoIEnumerableResponse.md)
 - [Model.GitlabProjectDtoResponse](docs/GitlabProjectDtoResponse.md)
 - [Model.GitlabResourceTypeOptionsForCreationDto](docs/GitlabResourceTypeOptionsForCreationDto.md)
 - [Model.GitlabResourceTypeOptionsForUpdateDto](docs/GitlabResourceTypeOptionsForUpdateDto.md)
 - [Model.HandleDto](docs/HandleDto.md)
 - [Model.HandleDtoResponse](docs/HandleDtoResponse.md)
 - [Model.HandleForUpdateDto](docs/HandleForUpdateDto.md)
 - [Model.HandleValueDto](docs/HandleValueDto.md)
 - [Model.HandleValueForUpdateDto](docs/HandleValueForUpdateDto.md)
 - [Model.HashParametersDto](docs/HashParametersDto.md)
 - [Model.IdentityProviderDto](docs/IdentityProviderDto.md)
 - [Model.IdentityProviders](docs/IdentityProviders.md)
 - [Model.LanguageDto](docs/LanguageDto.md)
 - [Model.LanguageDtoIEnumerableResponse](docs/LanguageDtoIEnumerableResponse.md)
 - [Model.LanguageDtoResponse](docs/LanguageDtoResponse.md)
 - [Model.LanguageForUserManipulationDto](docs/LanguageForUserManipulationDto.md)
 - [Model.LicenseDto](docs/LicenseDto.md)
 - [Model.LicenseDtoPagedResponse](docs/LicenseDtoPagedResponse.md)
 - [Model.LicenseDtoResponse](docs/LicenseDtoResponse.md)
 - [Model.LicenseForResourceManipulationDto](docs/LicenseForResourceManipulationDto.md)
 - [Model.MaintenanceDto](docs/MaintenanceDto.md)
 - [Model.MaintenanceDtoPagedResponse](docs/MaintenanceDtoPagedResponse.md)
 - [Model.MessageDto](docs/MessageDto.md)
 - [Model.MessageDtoPagedResponse](docs/MessageDtoPagedResponse.md)
 - [Model.MessageType](docs/MessageType.md)
 - [Model.MetadataTreeDto](docs/MetadataTreeDto.md)
 - [Model.MetadataTreeDtoPagedResponse](docs/MetadataTreeDtoPagedResponse.md)
 - [Model.MetadataTreeDtoResponse](docs/MetadataTreeDtoResponse.md)
 - [Model.MetadataTreeExtractedDto](docs/MetadataTreeExtractedDto.md)
 - [Model.MetadataTreeForCreationDto](docs/MetadataTreeForCreationDto.md)
 - [Model.MetadataTreeForDeletionDto](docs/MetadataTreeForDeletionDto.md)
 - [Model.MetadataTreeForUpdateDto](docs/MetadataTreeForUpdateDto.md)
 - [Model.MetadataUpdateAdminParameters](docs/MetadataUpdateAdminParameters.md)
 - [Model.OrganizationDto](docs/OrganizationDto.md)
 - [Model.OrganizationDtoPagedResponse](docs/OrganizationDtoPagedResponse.md)
 - [Model.OrganizationDtoResponse](docs/OrganizationDtoResponse.md)
 - [Model.OrganizationForProjectManipulationDto](docs/OrganizationForProjectManipulationDto.md)
 - [Model.Pagination](docs/Pagination.md)
 - [Model.PidDto](docs/PidDto.md)
 - [Model.PidDtoPagedResponse](docs/PidDtoPagedResponse.md)
 - [Model.PidDtoResponse](docs/PidDtoResponse.md)
 - [Model.PidRequestDto](docs/PidRequestDto.md)
 - [Model.PidType](docs/PidType.md)
 - [Model.ProjectAdminDto](docs/ProjectAdminDto.md)
 - [Model.ProjectAdminDtoPagedResponse](docs/ProjectAdminDtoPagedResponse.md)
 - [Model.ProjectDto](docs/ProjectDto.md)
 - [Model.ProjectDtoPagedResponse](docs/ProjectDtoPagedResponse.md)
 - [Model.ProjectDtoResponse](docs/ProjectDtoResponse.md)
 - [Model.ProjectForCreationDto](docs/ProjectForCreationDto.md)
 - [Model.ProjectForUpdateDto](docs/ProjectForUpdateDto.md)
 - [Model.ProjectInvitationDto](docs/ProjectInvitationDto.md)
 - [Model.ProjectInvitationDtoPagedResponse](docs/ProjectInvitationDtoPagedResponse.md)
 - [Model.ProjectInvitationDtoResponse](docs/ProjectInvitationDtoResponse.md)
 - [Model.ProjectInvitationForProjectManipulationDto](docs/ProjectInvitationForProjectManipulationDto.md)
 - [Model.ProjectInvitationResolveDto](docs/ProjectInvitationResolveDto.md)
 - [Model.ProjectMinimalDto](docs/ProjectMinimalDto.md)
 - [Model.ProjectOrganizationDto](docs/ProjectOrganizationDto.md)
 - [Model.ProjectPublicationRequestDto](docs/ProjectPublicationRequestDto.md)
 - [Model.ProjectPublicationRequestDtoResponse](docs/ProjectPublicationRequestDtoResponse.md)
 - [Model.ProjectQuotaDto](docs/ProjectQuotaDto.md)
 - [Model.ProjectQuotaDtoPagedResponse](docs/ProjectQuotaDtoPagedResponse.md)
 - [Model.ProjectQuotaDtoResponse](docs/ProjectQuotaDtoResponse.md)
 - [Model.ProjectQuotaForUpdateDto](docs/ProjectQuotaForUpdateDto.md)
 - [Model.ProjectResourceMinimalDto](docs/ProjectResourceMinimalDto.md)
 - [Model.ProjectRoleDto](docs/ProjectRoleDto.md)
 - [Model.ProjectRoleDtoPagedResponse](docs/ProjectRoleDtoPagedResponse.md)
 - [Model.ProjectRoleDtoResponse](docs/ProjectRoleDtoResponse.md)
 - [Model.ProjectRoleForProjectCreationDto](docs/ProjectRoleForProjectCreationDto.md)
 - [Model.ProjectRoleForProjectManipulationDto](docs/ProjectRoleForProjectManipulationDto.md)
 - [Model.ProjectRoleMinimalDto](docs/ProjectRoleMinimalDto.md)
 - [Model.ProvenanceDto](docs/ProvenanceDto.md)
 - [Model.ProvenanceDtoResponse](docs/ProvenanceDtoResponse.md)
 - [Model.ProvenanceForUpdateDto](docs/ProvenanceForUpdateDto.md)
 - [Model.ProvenanceParametersDto](docs/ProvenanceParametersDto.md)
 - [Model.PublicUserDto](docs/PublicUserDto.md)
 - [Model.PublicUserDtoIEnumerableResponse](docs/PublicUserDtoIEnumerableResponse.md)
 - [Model.PublicationAdvisoryServiceDto](docs/PublicationAdvisoryServiceDto.md)
 - [Model.PublicationRequestForCreationDto](docs/PublicationRequestForCreationDto.md)
 - [Model.QuotaDto](docs/QuotaDto.md)
 - [Model.QuotaForManipulationDto](docs/QuotaForManipulationDto.md)
 - [Model.QuotaUnit](docs/QuotaUnit.md)
 - [Model.RdfDefinitionDto](docs/RdfDefinitionDto.md)
 - [Model.RdfDefinitionDtoResponse](docs/RdfDefinitionDtoResponse.md)
 - [Model.RdfDefinitionForManipulationDto](docs/RdfDefinitionForManipulationDto.md)
 - [Model.RdfFormat](docs/RdfFormat.md)
 - [Model.RdfPatchDocumentDto](docs/RdfPatchDocumentDto.md)
 - [Model.RdfPatchOperationDto](docs/RdfPatchOperationDto.md)
 - [Model.RdfPatchOperationType](docs/RdfPatchOperationType.md)
 - [Model.RdsOptionsDto](docs/RdsOptionsDto.md)
 - [Model.RdsResourceTypeOptionsForManipulationDto](docs/RdsResourceTypeOptionsForManipulationDto.md)
 - [Model.RdsS3OptionsDto](docs/RdsS3OptionsDto.md)
 - [Model.RdsS3ResourceTypeOptionsForManipulationDto](docs/RdsS3ResourceTypeOptionsForManipulationDto.md)
 - [Model.RdsS3WormOptionsDto](docs/RdsS3WormOptionsDto.md)
 - [Model.RdsS3WormResourceTypeOptionsForManipulationDto](docs/RdsS3WormResourceTypeOptionsForManipulationDto.md)
 - [Model.ResourceAdminDto](docs/ResourceAdminDto.md)
 - [Model.ResourceAdminDtoPagedResponse](docs/ResourceAdminDtoPagedResponse.md)
 - [Model.ResourceContentPageColumnsDto](docs/ResourceContentPageColumnsDto.md)
 - [Model.ResourceContentPageDto](docs/ResourceContentPageDto.md)
 - [Model.ResourceContentPageEntriesViewDto](docs/ResourceContentPageEntriesViewDto.md)
 - [Model.ResourceContentPageMetadataViewDto](docs/ResourceContentPageMetadataViewDto.md)
 - [Model.ResourceCreationPageDto](docs/ResourceCreationPageDto.md)
 - [Model.ResourceDto](docs/ResourceDto.md)
 - [Model.ResourceDtoPagedResponse](docs/ResourceDtoPagedResponse.md)
 - [Model.ResourceDtoResponse](docs/ResourceDtoResponse.md)
 - [Model.ResourceForCreationDto](docs/ResourceForCreationDto.md)
 - [Model.ResourceForUpdateDto](docs/ResourceForUpdateDto.md)
 - [Model.ResourceMinimalDto](docs/ResourceMinimalDto.md)
 - [Model.ResourceQuotaDto](docs/ResourceQuotaDto.md)
 - [Model.ResourceQuotaDtoResponse](docs/ResourceQuotaDtoResponse.md)
 - [Model.ResourceTypeDto](docs/ResourceTypeDto.md)
 - [Model.ResourceTypeInformationDto](docs/ResourceTypeInformationDto.md)
 - [Model.ResourceTypeInformationDtoIEnumerableResponse](docs/ResourceTypeInformationDtoIEnumerableResponse.md)
 - [Model.ResourceTypeInformationDtoResponse](docs/ResourceTypeInformationDtoResponse.md)
 - [Model.ResourceTypeMinimalDto](docs/ResourceTypeMinimalDto.md)
 - [Model.ResourceTypeOptionsDto](docs/ResourceTypeOptionsDto.md)
 - [Model.ResourceTypeOptionsForCreationDto](docs/ResourceTypeOptionsForCreationDto.md)
 - [Model.ResourceTypeOptionsForUpdateDto](docs/ResourceTypeOptionsForUpdateDto.md)
 - [Model.ResourceTypeStatus](docs/ResourceTypeStatus.md)
 - [Model.RoleDto](docs/RoleDto.md)
 - [Model.RoleDtoPagedResponse](docs/RoleDtoPagedResponse.md)
 - [Model.RoleDtoResponse](docs/RoleDtoResponse.md)
 - [Model.RoleMinimalDto](docs/RoleMinimalDto.md)
 - [Model.SearchCategory](docs/SearchCategory.md)
 - [Model.SearchCategoryType](docs/SearchCategoryType.md)
 - [Model.SearchResultDto](docs/SearchResultDto.md)
 - [Model.SearchResultDtoPagedSearchResponse](docs/SearchResultDtoPagedSearchResponse.md)
 - [Model.TermsOfServiceDto](docs/TermsOfServiceDto.md)
 - [Model.TermsOfServiceDtoResponse](docs/TermsOfServiceDtoResponse.md)
 - [Model.TitleDto](docs/TitleDto.md)
 - [Model.TitleDtoIEnumerableResponse](docs/TitleDtoIEnumerableResponse.md)
 - [Model.TitleDtoResponse](docs/TitleDtoResponse.md)
 - [Model.TitleForUserManipulationDto](docs/TitleForUserManipulationDto.md)
 - [Model.TreeDataType](docs/TreeDataType.md)
 - [Model.UserDto](docs/UserDto.md)
 - [Model.UserDtoPagedResponse](docs/UserDtoPagedResponse.md)
 - [Model.UserDtoResponse](docs/UserDtoResponse.md)
 - [Model.UserEmailDto](docs/UserEmailDto.md)
 - [Model.UserForUpdateDto](docs/UserForUpdateDto.md)
 - [Model.UserMergeDto](docs/UserMergeDto.md)
 - [Model.UserMergeDtoResponse](docs/UserMergeDtoResponse.md)
 - [Model.UserMinimalDto](docs/UserMinimalDto.md)
 - [Model.UserOrganizationDto](docs/UserOrganizationDto.md)
 - [Model.UserTermsOfServiceAcceptDto](docs/UserTermsOfServiceAcceptDto.md)
 - [Model.VariantDto](docs/VariantDto.md)
 - [Model.VisibilityDto](docs/VisibilityDto.md)
 - [Model.VisibilityDtoPagedResponse](docs/VisibilityDtoPagedResponse.md)
 - [Model.VisibilityDtoResponse](docs/VisibilityDtoResponse.md)
 - [Model.VisibilityForProjectManipulationDto](docs/VisibilityForProjectManipulationDto.md)
 - [Model.VisibilityForResourceManipulationDto](docs/VisibilityForResourceManipulationDto.md)
 - [Model.VocabularyDto](docs/VocabularyDto.md)
 - [Model.VocabularyDtoPagedResponse](docs/VocabularyDtoPagedResponse.md)
 - [Model.VocabularyInstanceDto](docs/VocabularyInstanceDto.md)
 - [Model.VocabularyInstanceDtoPagedResponse](docs/VocabularyInstanceDtoPagedResponse.md)
 - [Model.VocabularyInstanceDtoResponse](docs/VocabularyInstanceDtoResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation for Authorization


Authentication schemes defined for the API:
<a id="Bearer"></a>
### Bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

