/*
 * Coscine Web API
 *
 * Coscine (short for <b>CO</b>llaborative <b>SC</b>ientific <b>IN</b>tegration <b>E</b>nvironment) is the research data management platform for your research project.
 *
 * The version of the OpenAPI document: 2.0
 * Contact: servicedesk@itc.rwth-aachen.de
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = Coscine.ApiClient.Core.Client.OpenAPIDateConverter;

namespace Coscine.ApiClient.Core.Model
{
    /// <summary>
    /// Represents the data transfer object (DTO) for creating GitLab resource type options.
    /// </summary>
    [DataContract(Name = "GitlabResourceTypeOptionsForCreationDto")]
    public partial class GitlabResourceTypeOptionsForCreationDto : IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="GitlabResourceTypeOptionsForCreationDto" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected GitlabResourceTypeOptionsForCreationDto() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="GitlabResourceTypeOptionsForCreationDto" /> class.
        /// </summary>
        /// <param name="branch">The branch associated with the GitLab resource. (required).</param>
        /// <param name="accessToken">The access token for authentication with GitLab. (required).</param>
        /// <param name="repoUrl">The repository URL for the GitLab resource. (required).</param>
        /// <param name="projectId">The project ID associated with the GitLab resource. (required).</param>
        /// <param name="tosAccepted">Indicates whether the terms of service for the GitLab resource are accepted. (required).</param>
        public GitlabResourceTypeOptionsForCreationDto(string branch = default(string), string accessToken = default(string), string repoUrl = default(string), int projectId = default(int), bool tosAccepted = default(bool))
        {
            // to ensure "branch" is required (not null)
            if (branch == null)
            {
                throw new ArgumentNullException("branch is a required property for GitlabResourceTypeOptionsForCreationDto and cannot be null");
            }
            this.Branch = branch;
            // to ensure "accessToken" is required (not null)
            if (accessToken == null)
            {
                throw new ArgumentNullException("accessToken is a required property for GitlabResourceTypeOptionsForCreationDto and cannot be null");
            }
            this.AccessToken = accessToken;
            // to ensure "repoUrl" is required (not null)
            if (repoUrl == null)
            {
                throw new ArgumentNullException("repoUrl is a required property for GitlabResourceTypeOptionsForCreationDto and cannot be null");
            }
            this.RepoUrl = repoUrl;
            this.ProjectId = projectId;
            this.TosAccepted = tosAccepted;
        }

        /// <summary>
        /// The branch associated with the GitLab resource.
        /// </summary>
        /// <value>The branch associated with the GitLab resource.</value>
        [DataMember(Name = "branch", IsRequired = true, EmitDefaultValue = true)]
        public string Branch { get; set; }

        /// <summary>
        /// The access token for authentication with GitLab.
        /// </summary>
        /// <value>The access token for authentication with GitLab.</value>
        [DataMember(Name = "accessToken", IsRequired = true, EmitDefaultValue = true)]
        public string AccessToken { get; set; }

        /// <summary>
        /// The repository URL for the GitLab resource.
        /// </summary>
        /// <value>The repository URL for the GitLab resource.</value>
        [DataMember(Name = "repoUrl", IsRequired = true, EmitDefaultValue = true)]
        public string RepoUrl { get; set; }

        /// <summary>
        /// The project ID associated with the GitLab resource.
        /// </summary>
        /// <value>The project ID associated with the GitLab resource.</value>
        [DataMember(Name = "projectId", IsRequired = true, EmitDefaultValue = true)]
        public int ProjectId { get; set; }

        /// <summary>
        /// Indicates whether the terms of service for the GitLab resource are accepted.
        /// </summary>
        /// <value>Indicates whether the terms of service for the GitLab resource are accepted.</value>
        [DataMember(Name = "tosAccepted", IsRequired = true, EmitDefaultValue = true)]
        public bool TosAccepted { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class GitlabResourceTypeOptionsForCreationDto {\n");
            sb.Append("  Branch: ").Append(Branch).Append("\n");
            sb.Append("  AccessToken: ").Append(AccessToken).Append("\n");
            sb.Append("  RepoUrl: ").Append(RepoUrl).Append("\n");
            sb.Append("  ProjectId: ").Append(ProjectId).Append("\n");
            sb.Append("  TosAccepted: ").Append(TosAccepted).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        IEnumerable<ValidationResult> IValidatableObject.Validate(ValidationContext validationContext)
        {
            // Branch (string) minLength
            if (this.Branch != null && this.Branch.Length < 1)
            {
                yield return new ValidationResult("Invalid value for Branch, length must be greater than 1.", new [] { "Branch" });
            }

            // AccessToken (string) minLength
            if (this.AccessToken != null && this.AccessToken.Length < 1)
            {
                yield return new ValidationResult("Invalid value for AccessToken, length must be greater than 1.", new [] { "AccessToken" });
            }

            // ProjectId (int) maximum
            if (this.ProjectId > (int)2147483647)
            {
                yield return new ValidationResult("Invalid value for ProjectId, must be a value less than or equal to 2147483647.", new [] { "ProjectId" });
            }

            // ProjectId (int) minimum
            if (this.ProjectId < (int)1)
            {
                yield return new ValidationResult("Invalid value for ProjectId, must be a value greater than or equal to 1.", new [] { "ProjectId" });
            }

            yield break;
        }
    }

}
